shouldProcessSent method
Returns true when the sent message should be logged.
Implementation
bool shouldProcessSent(ISpectLogData value) {
if (sentChain != null) return sentChain!.apply(value);
return sentFilter?.call(value) ?? true;
}
Returns true when the sent message should be logged.
bool shouldProcessSent(ISpectLogData value) {
if (sentChain != null) return sentChain!.apply(value);
return sentFilter?.call(value) ?? true;
}