settings property
Filtering, redaction toggle, and print toggles for emitted logs.
Implementation
final ISpectWSInterceptorSettings settings;
Filtering, redaction toggle, and print toggles for emitted logs.
final ISpectWSInterceptorSettings settings;